Struct rkyv::collections::index_map::ArchivedIndexMap [−][src]
pub struct ArchivedIndexMap<K, V> { /* fields omitted */ }Expand description
An archived IndexMap.
Implementations
Returns whether a key is present in the hash map.
Gets the value associated with the given key.
Gets the index, key, and value associated with the given key.
Gets the index of a key if it exists in the map.
Gets the key-value pair associated with the given key.
Gets the hasher for this index map.
Returns an iterator over the key-value pairs of the map in order
Returns an iterator over the keys of the map in order
Returns an iterator over the values of the map in order.
pub unsafe fn resolve_from_len(
len: usize,
pos: usize,
resolver: IndexMapResolver,
out: *mut Self
)
pub unsafe fn resolve_from_len(
len: usize,
pos: usize,
resolver: IndexMapResolver,
out: *mut Self
)
Resolves an archived index map from a given length and parameters.
Safety
lenmust be the number of elements that were serializedposmust be the position ofoutwithin the archiveresolvermust be the result of serializing a hash map